==> com.precisely.apis-11.9.2-py3-none-any.whl: com/precisely/apis/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.address_verification_service_api import AddressVerificationServiceApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from com.precisely.apis.api.address_verification_service_api import AddressVerificationServiceApi
from com.precisely.apis.api.addresses_service__api import AddressesServiceApi
from com.precisely.apis.api.demographics_service_api import DemographicsServiceApi
from com.precisely.apis.api.email_verification_service_api import EmailVerificationServiceApi
from com.precisely.apis.api.geocode_service_api import GeocodeServiceApi
from com.precisely.apis.api.geolocation_service_api import GeolocationServiceApi
from com.precisely.apis.api.local_tax_service_api import LocalTaxServiceApi
from com.precisely.apis.api.neighborhoods_service__api import NeighborhoodsServiceApi
from com.precisely.apis.api.psap_911_service_api import PSAP911ServiceApi
from com.precisely.apis.api.phone_verification_service_api import PhoneVerificationServiceApi
from com.precisely.apis.api.places_service__api import PlacesServiceApi
from com.precisely.apis.api.property_information_service_api import PropertyInformationServiceApi
from com.precisely.apis.api.risks_service_api import RisksServiceApi
from com.precisely.apis.api.routing_service_api import RoutingServiceApi
from com.precisely.apis.api.schools_service_api import SchoolsServiceApi
from com.precisely.apis.api.streets_service_api import StreetsServiceApi
from com.precisely.apis.api.telecomm_info_service_api import TelecommInfoServiceApi
from com.precisely.apis.api.time_zone_service_api import TimeZoneServiceApi
from com.precisely.apis.api.typeahead_service_api import TypeaheadServiceApi
from com.precisely.apis.api.zones_service_api import ZonesServiceApi

==> com.precisely.apis-11.9.4-py3-none-any.whl: com/precisely/apis/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.address_autocomplete_service_api import AddressAutocompleteServiceApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from com.precisely.apis.api.address_autocomplete_service_api import AddressAutocompleteServiceApi
from com.precisely.apis.api.address_verification_service_api import AddressVerificationServiceApi
from com.precisely.apis.api.addresses_service__api import AddressesServiceApi
from com.precisely.apis.api.demographics_service_api import DemographicsServiceApi
from com.precisely.apis.api.email_verification_service_api import EmailVerificationServiceApi
from com.precisely.apis.api.geocode_service_api import GeocodeServiceApi
from com.precisely.apis.api.geolocation_service_api import GeolocationServiceApi
from com.precisely.apis.api.local_tax_service_api import LocalTaxServiceApi
from com.precisely.apis.api.neighborhoods_service__api import NeighborhoodsServiceApi
from com.precisely.apis.api.psap_911_service_api import PSAP911ServiceApi
from com.precisely.apis.api.phone_verification_service_api import PhoneVerificationServiceApi
from com.precisely.apis.api.places_service__api import PlacesServiceApi
from com.precisely.apis.api.property_information_service_api import PropertyInformationServiceApi
from com.precisely.apis.api.risks_service_api import RisksServiceApi
from com.precisely.apis.api.routing_service_api import RoutingServiceApi
from com.precisely.apis.api.schools_service_api import SchoolsServiceApi
from com.precisely.apis.api.streets_service_api import StreetsServiceApi
from com.precisely.apis.api.telecomm_info_service_api import TelecommInfoServiceApi
from com.precisely.apis.api.time_zone_service_api import TimeZoneServiceApi
from com.precisely.apis.api.zones_service_api import ZonesServiceApi
